@@ -57,7 +57,7 @@ class logger:
             log_format = logging.Formatter(fmt='%(levelname)s - %(asctime)s.%(msecs)03d - Line %(lineno)s: %(message)s', datefmt='%H:%M:%S')
             self.log_file.setFormatter(log_format)
 
-        log_file = open(filename, 'r+').read()
+        log_file = open(self.filename, 'r+').read()
         number_of_lines = len(log_file.splitlines())
         if number_of_lines > self.max_lines:
             self.logger.info('Resetting log file')
